@@ -1,8 +1,4 @@
 
-#' @export
-ci.flexsurvreg <- ci.tobit
-
-
 #' @export
 standard_error.flexsurvreg <- function(model, ...) {
   params <- insight::find_parameters(model, flatten = TRUE)
@@ -15,6 +11,8 @@ standard_error.flexsurvreg <- function(model, ...) {
 }
 
 
+## TODO add ci_method later?
+
 #' @export
 p_value.flexsurvreg <- function(model, ...) {
   params <- insight::get_parameters(model)
