@@ -8,7 +8,7 @@ model_parameters.model_fit <- function(model,
                                        ci = .95,
                                        effects = "fixed",
                                        component = "conditional",
-                                       df_method = "profile",
+                                       ci_method = "profile",
                                        bootstrap = FALSE,
                                        iterations = 1000,
                                        standardize = NULL,
@@ -22,7 +22,7 @@ model_parameters.model_fit <- function(model,
     ci = ci,
     effects = effects,
     component = component,
-    df_method = df_method,
+    ci_method = ci_method,
     bootstrap = bootstrap,
     iterations = iterations,
     standardize = standardize,
