@@ -7,41 +7,47 @@
 #' with the fewer factors.
 #'
 #' @param x A data frame.
-#' @param type Can be \code{"FA"} or \code{"PCA"}, depending on what you want to
+#' @param type Can be `"FA"` or `"PCA"`, depending on what you want to
 #'   do.
 #' @param rotation Only used for VSS (Very Simple Structure criterion, see
-#'   \code{\link[psych]{VSS}}). The rotation to apply. Can be \code{"none"},
-#'   \code{"varimax"}, \code{"quartimax"}, \code{"bentlerT"}, \code{"equamax"},
-#'   \code{"varimin"}, \code{"geominT"} and \code{"bifactor"} for orthogonal
-#'   rotations, and \code{"promax"}, \code{"oblimin"}, \code{"simplimax"},
-#'   \code{"bentlerQ"}, \code{"geominQ"}, \code{"biquartimin"} and
-#'   \code{"cluster"} for oblique transformations.
-#' @param algorithm Factoring method used by VSS. Can be \code{"pa"} for
-#'   Principal Axis Factor Analysis, \code{"minres"} for minimum residual (OLS)
-#'   factoring, \code{"mle"} for Maximum Likelihood FA and \code{"pc"} for
-#'   Principal Components. \code{"default"} will select \code{"minres"} if
-#'   \code{type = "FA"} and \code{"pc"} if \code{type = "PCA"}.
+#'   [psych::VSS()]). The rotation to apply. Can be `"none"`,
+#'   `"varimax"`, `"quartimax"`, `"bentlerT"`, `"equamax"`,
+#'   `"varimin"`, `"geominT"` and `"bifactor"` for orthogonal
+#'   rotations, and `"promax"`, `"oblimin"`, `"simplimax"`,
+#'   `"bentlerQ"`, `"geominQ"`, `"biquartimin"` and
+#'   `"cluster"` for oblique transformations.
+#' @param algorithm Factoring method used by VSS. Can be `"pa"` for
+#'   Principal Axis Factor Analysis, `"minres"` for minimum residual (OLS)
+#'   factoring, `"mle"` for Maximum Likelihood FA and `"pc"` for
+#'   Principal Components. `"default"` will select `"minres"` if
+#'   `type = "FA"` and `"pc"` if `type = "PCA"`.
 #' @param package Package from which respective methods are used. Can be
-#'   \code{"all"} or a vector containing \code{"nFactors"}, \code{"psych"} and
-#'   \code{"EGAnet"}. However, \code{"EGAnet"} can be very slow for bigger
-#'   datasets. Thus, by default, \code{c("nFactors", "psych")} are selected.
-#' @param safe If \code{TRUE}, the function will run all the procedures in try
+#'   `"all"` or a vector containing `"nFactors"`, `"psych"`, `"PCDimension"`, `"fit"` or
+#'   `"EGAnet"`. Note that `"fit"` (which actually also relies on the `psych`
+#'   package) and `"EGAnet"` can be very slow for bigger
+#'   datasets. Thus, the default is `c("nFactors", "psych")`. You must have
+#'   the respective packages installed for the methods to be used.
+#' @param safe If `TRUE`, the function will run all the procedures in try
 #'   blocks, and will only return those that work and silently skip the ones
 #'   that may fail.
 #' @param cor An optional correlation matrix that can be used (note that the
-#'   data must still be passed as the first argument). If \code{NULL}, will
-#'   compute it by running \code{cor()} on the passed data.
+#'   data must still be passed as the first argument). If `NULL`, will
+#'   compute it by running `cor()` on the passed data.
+#' @param n_max If set to a value (e.g., `10`), will drop from the results all
+#' methods that suggest a higher number of components. The interpretation becomes
+#' 'from all the methods that suggested a number lower than n_max, the results
+#' are ...'.
 #' @param ... Arguments passed to or from other methods.
 #'
-#' @details \code{n_components} is actually an alias for \code{n_factors}, with
+#' @details `n_components` is actually an alias for `n_factors`, with
 #'   different defaults for the function arguments.
 #'
 #' @note There is also a
-#'   \href{https://easystats.github.io/see/articles/parameters.html}{\code{plot()}-method}
+#'   [`plot()`-method](https://easystats.github.io/see/articles/parameters.html)
 #'   implemented in the
 #'   \href{https://easystats.github.io/see/}{\pkg{see}-package}.
-#'   \code{n_components()} is a convenient short for \code{n_factors(type =
-#'   "PCA")}.
+#'   `n_components()` is a convenient short for `n_factors(type =
+#'   "PCA")`.
 #'
 #' @examples
 #' library(parameters)
@@ -51,10 +57,13 @@
 #'   result <- n_factors(mtcars[1:5], type = "FA")
 #'   as.data.frame(result)
 #'   summary(result)
-#'   \donttest{
-#'   n_factors(mtcars, type = "PCA", package = "all")
-#'   n_factors(mtcars, type = "FA", algorithm = "mle", package = "all")
-#' }
+#'   \dontrun{
+#'   if (require("PCDimension", quietly = TRUE)) {
+#'     # Setting package = 'all' will increase the number of methods (but is slow)
+#'     n_factors(mtcars, type = "PCA", package = "all")
+#'     n_factors(mtcars, type = "FA", algorithm = "mle", package = "all")
+#'   }
+#'   }
 #' }
 #' @return A data frame.
 #'
@@ -110,29 +119,44 @@ n_factors <- function(x,
                       package = c("nFactors", "psych"),
                       cor = NULL,
                       safe = TRUE,
+                      n_max = NULL,
                       ...) {
   if (all(package == "all")) {
-    package <- c("nFactors", "EGAnet", "psych")
+    package <- c("nFactors", "EGAnet", "psych", "fit", "pcdimension")
   }
 
-  # Initialize parameters
-  nobs <- nrow(x)
+  # Get number of observations
+  if(!is.data.frame(x)) {
+    if(is.numeric(x) && !is.null(cor)) {
+      nobs <- x
+      package <- package[!package %in% c("pcdimension", "PCDimension")]
+    } else if(is.matrix(x) || inherits(x, "easycormatrix")) {
+      stop("Please input the correlation matrix via the `cor = ...` argument and
+           the number of rows / observations via the first argument.")
+    }
+  } else {
+    nobs <- nrow(x)
+  }
 
   # Correlation matrix
   if (is.null(cor)) {
-    cor <- stats::cor(x, use = "pairwise.complete.obs")
+    cor <- stats::cor(x, use = "pairwise.complete.obs", ...)
   }
   eigen_values <- eigen(cor)$values
 
+  # Smooth matrix if negative eigen values
+  if(any(eigen_values < 0)) {
+    insight::check_if_installed("psych")
+    cor <- psych::cor.smooth(cor, ...)
+    eigen_values <- eigen(cor)$values
+  }
 
   # Initialize dataframe
   out <- data.frame()
 
   # nFactors -------------------------------------------
   if ("nFactors" %in% package) {
-    if (!requireNamespace("nFactors", quietly = TRUE)) {
-      stop("Package 'nFactors' required for this function to work. Please install it by running `install.packages('nFactors')`.")
-    }
+    insight::check_if_installed("nFactors")
 
     # Model
     if (tolower(type) %in% c("fa", "factor", "efa")) {
@@ -214,10 +238,8 @@ n_factors <- function(x,
   }
 
   # EGAnet -------------------------------------------
-  if ("EGAnet" %in% c(package)) {
-    if (!requireNamespace("EGAnet", quietly = TRUE)) {
-      stop("Package 'EGAnet' required for this function to work. Please install it by running `install.packages('EGAnet')`.")
-    }
+  if ("EGAnet" %in% package) {
+    insight::check_if_installed("EGAnet")
 
     if (safe) {
       out <- rbind(
@@ -237,10 +259,8 @@ n_factors <- function(x,
 
 
   # psych -------------------------------------------
-  if ("psych" %in% c(package)) {
-    if (!requireNamespace("psych", quietly = TRUE)) {
-      stop("Package 'psych' required for this function to work. Please install it by running `install.packages('psych')`.")
-    }
+  if ("psych" %in% package) {
+    insight::check_if_installed("psych")
 
     if (safe) {
       out <- rbind(
@@ -250,6 +270,19 @@ n_factors <- function(x,
           error = function(e) data.frame()
         )
       )
+    } else {
+      out <- rbind(
+        out,
+        .n_factors_vss(x, cor, nobs, type, rotation, algorithm)
+      )
+    }
+  }
+
+  # fit -------------------------------------------
+  if ("fit" %in% package) {
+    insight::check_if_installed("psych")
+
+    if (safe) {
       out <- rbind(
         out,
         tryCatch(.n_factors_fit(x, cor, nobs, type, rotation, algorithm),
@@ -260,22 +293,41 @@ n_factors <- function(x,
     } else {
       out <- rbind(
         out,
-        .n_factors_vss(x, cor, nobs, type, rotation, algorithm)
+        .n_factors_fit(x, cor, nobs, type, rotation, algorithm)
       )
+    }
+  }
+
+  # fit -------------------------------------------
+  if ("pcdimension" %in% tolower(package)) {
+    insight::check_if_installed("PCDimension")
+
+    if (safe) {
       out <- rbind(
         out,
-        .n_factors_fit(x, cor, nobs, type, rotation, algorithm)
+        tryCatch(.n_factors_PCDimension(x, type),
+                 warning = function(w) data.frame(),
+                 error = function(e) data.frame()
+        )
+      )
+    } else {
+      out <- rbind(
+        out,
+        .n_factors_PCDimension(x, type)
       )
     }
   }
 
   # OUTPUT ----------------------------------------------
   # TODO created weighted composite score
-
   out <- out[!is.na(out$n_Factors), ] # Remove empty methods
   out <- out[order(out$n_Factors), ] # Arrange by n factors
   row.names(out) <- NULL # Reset row index
 
+  if(!is.null(n_max)) {
+    out <-  out[out$n_Factors <= n_max, ]
+  }
+
   # Add summary
   by_factors <- .data_frame(
     n_Factors = as.numeric(unique(out$n_Factors)),
@@ -368,8 +420,6 @@ as.numeric.n_factors <- function(x, ...) {
 #' @export
 as.double.n_factors <- as.numeric.n_factors
 
-
-
 #' @export
 summary.n_clusters <- summary.n_factors
 
@@ -383,6 +433,7 @@ as.double.n_clusters <- as.double.n_factors
 print.n_clusters <- print.n_factors
 
 
+# Methods -----------------------------------------------------------------
 
 
 #' Bartlett, Anderson and Lawley Procedures
@@ -391,9 +442,9 @@ print.n_clusters <- print.n_factors
   nfac <- nFactors::nBartlett(
     eigen_values,
     N = nobs,
+    cor = TRUE,
     alpha = 0.05,
-    details = FALSE,
-    model = model
+    details = FALSE
   )$nFactors
 
   data.frame(
@@ -476,7 +527,7 @@ print.n_clusters <- print.n_factors
   nfac <- nFactors::nSeScree(x = eigen_values, cor = TRUE, model = model)$nFactors
   data.frame(
     n_Factors = as.numeric(nfac),
-    Method = c("SE Scree", "R2"),
+    Method = c("Scree (SE)", "Scree (R2)"),
     Family = "Scree_SE"
   )
 }
@@ -492,11 +543,10 @@ print.n_clusters <- print.n_factors
                            eigen_values = NULL,
                            type = "FA") {
 
+
   # Replace with own correlation matrix
-  junk <- utils::capture.output(suppressWarnings(suppressMessages(nfac_glasso <- EGAnet::EGA(x, model = "glasso", plot.EGA = FALSE)$n.dim)))
-  junk <- utils::capture.output(suppressWarnings(suppressMessages(nfac_TMFG <- EGAnet::EGA(x, model = "TMFG", plot.EGA = FALSE)$n.dim)))
-  # junk <- utils::capture.output(suppressWarnings(suppressMessages(nfac_glasso_boot <- EGAnet::bootEGA(x, model = "glasso", n = 500, plot.typicalStructure = FALSE)$n.dim)))
-  # junk <- utils::capture.output(suppressWarnings(suppressMessages(nfac_TMFG_boot <- EGAnet::bootEGA(x, model = "TMFG", n = 500, plot.typicalStructure = FALSE)$n.dim)))
+  junk <- utils::capture.output(suppressWarnings(suppressMessages(nfac_glasso <- EGAnet::EGA(cor, n = nobs, model = "glasso", plot.EGA = FALSE)$n.dim)))
+  junk <- utils::capture.output(suppressWarnings(suppressMessages(nfac_TMFG <- EGAnet::EGA(cor, n = nobs, model = "TMFG", plot.EGA = FALSE)$n.dim)))
 
   data.frame(
     n_Factors = as.numeric(c(nfac_glasso, nfac_TMFG)),
@@ -565,7 +615,8 @@ print.n_clusters <- print.n_factors
                            nobs = NULL,
                            type = "FA",
                            rotation = "varimax",
-                           algorithm = "default") {
+                           algorithm = "default",
+                           threshold = 0.1) {
   if (algorithm == "default") {
     if (tolower(type) %in% c("fa", "factor", "efa")) {
       algorithm <- "minres"
@@ -577,22 +628,20 @@ print.n_clusters <- print.n_factors
   rez <- data.frame()
   for (n in 1:(ncol(cor) - 1)) {
     if (tolower(type) %in% c("fa", "factor", "efa")) {
-      factors <- tryCatch(psych::fa(cor,
+      factors <- tryCatch(suppressWarnings(psych::fa(cor,
         nfactors = n,
         n.obs = nobs,
         rotate = rotation,
         fm = algorithm
-      ),
-      warning = function(w) NA,
+      )),
       error = function(e) NA
       )
     } else {
-      factors <- tryCatch(psych::pca(cor,
+      factors <- tryCatch(suppressWarnings(psych::pca(cor,
         nfactors = n,
         n.obs = nobs,
         rotate = rotation
-      ),
-      warning = function(w) NA,
+      )),
       error = function(e) NA
       )
     }
@@ -611,8 +660,8 @@ print.n_clusters <- print.n_factors
       rez,
       data.frame(
         n = n,
-        TLI = tli,
         Fit = factors$fit.off,
+        TLI = tli,
         RMSEA = rmsea,
         RMSR = rmsr,
         CRMS = crms,
@@ -621,20 +670,92 @@ print.n_clusters <- print.n_factors
     )
   }
 
-  TLI <- ifelse(all(is.na(rez$TLI)), NA, rez[!is.na(rez$TLI) & rez$TLI == min(rez$TLI, na.rm = TRUE), "n"])
-  RMSEA <- ifelse(all(is.na(rez$RMSEA)), NA, rez[!is.na(rez$RMSEA) & rez$RMSEA == max(rez$RMSEA, na.rm = TRUE), "n"])
-  RMSR <- ifelse(all(is.na(rez$RMSR)), NA, rez[!is.na(rez$RMSR) & rez$RMSR == min(rez$RMSR, na.rm = TRUE), "n"])
-  CRMS <- ifelse(all(is.na(rez$CRMS)), NA, rez[!is.na(rez$CRMS) & rez$CRMS == min(rez$CRMS, na.rm = TRUE), "n"])
+  # For fit indices that constantly increase / decrease, we need to find
+  # an "elbow"/"knee". Here we take the first value that reaches 90 percent
+  # of the range between the max and the min (when 'threshold = 0.1').
+  # Fit
+  if(all(is.na(rez$Fit))) {
+    fit_off <- NA
+  } else {
+    target <- max(rez$Fit, na.rm = TRUE) - threshold * diff(range(rez$Fit, na.rm = TRUE))
+    fit_off <- rez[!is.na(rez$Fit) & rez$Fit >= target, "n"][1]
+  }
+  # TLI
+  if(all(is.na(rez$TLI))) {
+    TLI <- NA
+  } else {
+    target <- max(rez$TLI, na.rm = TRUE) - threshold * diff(range(rez$TLI, na.rm = TRUE))
+    TLI <- rez[!is.na(rez$TLI) & rez$TLI >= target, "n"][1]
+  }
+  # RMSEA
+  if(all(is.na(rez$RMSEA))) {
+    RMSEA <- NA
+  } else {
+    target <- min(rez$RMSEA, na.rm = TRUE) + threshold * diff(range(rez$RMSEA, na.rm = TRUE))
+    RMSEA <- rez[!is.na(rez$RMSEA) & rez$RMSEA <= target, "n"][1]
+  }
+  # RMSR
+  if(all(is.na(rez$RMSR))) {
+    RMSR <- NA
+  } else {
+    target <- min(rez$RMSR, na.rm = TRUE) + threshold * diff(range(rez$RMSR, na.rm = TRUE))
+    RMSR <- rez[!is.na(rez$RMSR) & rez$RMSR <= target, "n"][1]
+  }
+  # CRMS
+  if(all(is.na(rez$CRMS))) {
+    CRMS <- NA
+  } else {
+    target <- min(rez$CRMS, na.rm = TRUE) + threshold * diff(range(rez$CRMS, na.rm = TRUE))
+    CRMS <- rez[!is.na(rez$CRMS) & rez$CRMS <= target, "n"][1]
+  }
+  # BIC (this is a penalized method so we can just take the one that minimizes it)
   BIC <- ifelse(all(is.na(rez$BIC)), NA, rez[!is.na(rez$BIC) & rez$BIC == min(rez$BIC, na.rm = TRUE), "n"])
 
   data.frame(
-    n_Factors = c(TLI, RMSEA, CRMS, BIC),
-    Method = c("TLI", "RMSEA", "CRMS", "BIC"),
-    Family = c("Fit", "Fit", "Fit", "Fit")
+    n_Factors = c(fit_off, TLI, RMSEA, RMSR, CRMS, BIC),
+    Method = c("Fit_off", "TLI", "RMSEA", "RMSR", "CRMS", "BIC"),
+    Family = c("Fit", "Fit", "Fit", "Fit", "Fit", "Fit")
   )
 }
 
+# PCDimension ------------------------
 
+#' @keywords internal
+.n_factors_PCDimension <- function(x = NULL, type = "PCA") {
+  # This package is a strict dependency of PCDimension so if users have the
+  # former they should have it
+  insight::check_if_installed("ClassDiscovery")
+
+  # Only applies to PCA with full data
+  if(tolower(type) %in% c("fa", "factor", "efa") || !is.data.frame(x)) {
+    return(data.frame())
+  }
+  # Randomization-Based Methods
+  rez_rnd <- PCDimension::rndLambdaF(x)
+
+  # Broken-Stick
+  spca <- ClassDiscovery::SamplePCA(t(x))
+  lambda <- spca@variances[1:(ncol(x)-1)]
+  rez_bokenstick <- PCDimension::bsDimension(lambda)
+
+  # Auer-Gervini
+  ag <- PCDimension::AuerGervini(spca)
+  agfuns <- list(twice=PCDimension::agDimTwiceMean,
+                 specc=PCDimension::agDimSpectral,
+                 km=PCDimension::agDimKmeans,
+                 km3=PCDimension::agDimKmeans3,
+                 # tt=PCDimension::agDimTtest,  # known to overestimate
+                 # cpm=PCDimension::makeAgCpmFun("Exponential"), # known to overestimate
+                 tt2=PCDimension::agDimTtest2,
+                 cpt=PCDimension::agDimCPT)
+  rez_ag <- PCDimension::compareAgDimMethods(ag, agfuns)
+
+  data.frame(
+    n_Factors = as.numeric(c(rez_rnd, rez_bokenstick, rez_ag)),
+    Method = c("Random (lambda)", "Random (F)", "Broken-Stick", "Auer-Gervini (twice)", "Auer-Gervini (spectral)", "Auer-Gervini (kmeans-2)", "AuerGervini (kmeans-3)", "Auer-Gervini (T)", "AuerGervini (CPT)"),
+    Family = "PCDimension"
+  )
+}
 
 # Re-implementation of nBentler in nFactors ------------------------
 
@@ -647,9 +768,7 @@ print.n_clusters <- print.n_factors
                       cor = TRUE,
                       details = TRUE,
                       ...) {
-  if (!requireNamespace("nFactors", quietly = TRUE)) {
-    stop("Package 'nFactors' required for this function to work. Please install it by running `install.packages('lattice')`.")
-  }
+  insight::check_if_installed("nFactors")
 
   lambda <- nFactors::eigenComputes(x, cor = cor, model = model, ...)
   if (length(which(lambda < 0)) > 0) {
