@@ -9,20 +9,20 @@
 #'
 #' @references Gelman A, Hill J. Data analysis using regression and multilevel/hierarchical models. Cambridge; New York: Cambridge University Press 2007: 140-143
 #'
-#' @seealso \code{\link{bootstrap_model}}, \code{\link{bootstrap_parameters}}, \code{\link{simulate_model}}
+#' @seealso [bootstrap_model()], [bootstrap_parameters()], [simulate_model()]
 #'
-#' @note There is also a \href{https://easystats.github.io/see/articles/parameters.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/parameters.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @details
 #'   \subsection{Technical Details}{
-#'     \code{simulate_parameters()} is a computationally faster alternative
-#'     to \code{bootstrap_parameters()}. Simulated draws for coefficients are based
-#'     on a multivariate normal distribution (\code{MASS::mvrnorm()}) with mean
-#'     \code{mu = coef(model)} and variance \code{Sigma = vcov(model)}.
+#'     `simulate_parameters()` is a computationally faster alternative
+#'     to `bootstrap_parameters()`. Simulated draws for coefficients are based
+#'     on a multivariate normal distribution (`MASS::mvrnorm()`) with mean
+#'     `mu = coef(model)` and variance `Sigma = vcov(model)`.
 #'   }
 #'   \subsection{Models with Zero-Inflation Component}{
 #'     For models from packages \pkg{glmmTMB}, \pkg{pscl}, \pkg{GLMMadaptive} and
-#'     \pkg{countreg}, the \code{component} argument can be used to specify
+#'     \pkg{countreg}, the `component` argument can be used to specify
 #'     which parameters should be simulated. For all other models, parameters
 #'     from the conditional component (fixed effects) are simulated. This may
 #'     include smooth terms, but not random effects.
@@ -72,7 +72,7 @@ simulate_parameters.default <- function(model,
     ...
   )
 
-  params <- insight::get_parameters(model)
+  params <- insight::get_parameters(model, verbose = FALSE)
   if ("Effects" %in% colnames(params) && .n_unique(params$Effects) > 1) {
     out$Effects <- params$Effects
   }
