@@ -1,4 +1,4 @@
-if (require("testthat") && require("parameters") && require("bbmle")) {
+if (requiet("testthat") && requiet("parameters") && requiet("bbmle")) {
   x <- 0:10
   y <- c(26, 17, 13, 12, 20, 5, 9, 8, 5, 4, 8)
   d <- data.frame(x, y)
